export declare namespace v10_1_0 {
    interface ProjectJson {
        typeDocJsonParserVersion: string;
        id: number;
        name: string;
        version: string | null;
        dependencies: Record<string, string>;
        readme: string | null;
        changelog: string | null;
        classes: ClassJson[];
        enums: EnumJson[];
        functions: FunctionJson[];
        interfaces: InterfaceJson[];
        namespaces: NamespaceJson[];
        typeAliases: TypeAliasJson[];
        variables: VariableJson[];
    }
    interface ParserJson {
        id: number;
        name: string;
        source: Misc.SourceJson;
    }
    namespace Misc {
        interface CommentJson {
            description: string | null;
            blockTags: CommentJson.BlockTagJson[];
            modifierTags: string[];
        }
        namespace CommentJson {
            interface BlockTagJson {
                name: string;
                text: string;
            }
        }
        interface ParameterJson {
            id: number;
            comment: CommentJson;
            name: string;
            optional: boolean;
            rest: boolean;
            type: TypeJson;
        }
        interface SignatureJson {
            id: number;
            name: string;
            comment: CommentJson;
            typeParameters: TypeParameterJson[];
            parameters: ParameterJson[];
            returnType: TypeJson;
        }
        interface SourceJson {
            line: number;
            file: string;
            path: string;
            url: string | null;
        }
        interface TypeParameterJson {
            id: number;
            name: string;
            constraint: TypeJson | null;
            default: TypeJson | null;
        }
    }
    interface TypeJson {
        kind: TypeJson.Kind;
    }
    namespace TypeJson {
        enum Kind {
            Array = "array",
            Conditional = "conditional",
            IndexedAccess = "indexedAccess",
            Inferred = "inferred",
            Intersection = "intersection",
            Intrinsic = "intrinsic",
            Literal = "literal",
            Mapped = "mapped",
            NamedTupleMember = "namedTupleMember",
            Optional = "optional",
            Predicate = "predicate",
            Query = "query",
            Reference = "reference",
            Reflection = "reflection",
            Rest = "rest",
            TemplateLiteral = "templateLiteral",
            Tuple = "tuple",
            TypeOperator = "typeOperator",
            Union = "union",
            Unknown = "unknown"
        }
    }
    interface ClassJson extends ParserJson {
        external: boolean;
        namespaceParentId: number | null;
        comment: Misc.CommentJson;
        abstract: boolean;
        typeParameters: Misc.TypeParameterJson[];
        extendsType: TypeJson | null;
        implementsType: TypeJson[];
        construct: ClassJson.ConstructorJson;
        properties: ClassJson.PropertyJson[];
        methods: ClassJson.MethodJson[];
    }
    namespace ClassJson {
        enum Accessibility {
            Public = "public",
            Protected = "protected",
            Private = "private"
        }
        interface ConstructorJson extends ParserJson {
            parentId: number;
            comment: Misc.CommentJson;
            accessibility: Accessibility;
            parameters: Misc.ParameterJson[];
        }
        interface PropertyJson extends ParserJson {
            parentId: number;
            comment: Misc.CommentJson;
            accessibility: Accessibility;
            abstract: boolean;
            static: boolean;
            readonly: boolean;
            optional: boolean;
            type: TypeJson;
        }
        interface MethodJson extends ParserJson {
            parentId: number;
            accessibility: Accessibility;
            abstract: boolean;
            static: boolean;
            signatures: Misc.SignatureJson[];
        }
    }
    interface EnumJson extends ParserJson {
        external: boolean;
        namespaceParentId: number | null;
        comment: Misc.CommentJson;
        members: EnumJson.MemberJson[];
    }
    namespace EnumJson {
        interface MemberJson extends ParserJson {
            parentId: number;
            comment: Misc.CommentJson;
            value: string;
        }
    }
    interface FunctionJson extends ParserJson {
        external: boolean;
        namespaceParentId: number | null;
        comment: Misc.CommentJson;
        signatures: Misc.SignatureJson[];
    }
    interface InterfaceJson extends ParserJson {
        external: boolean;
        namespaceParentId: number | null;
        comment: Misc.CommentJson;
        typeParameters: Misc.TypeParameterJson[];
        properties: InterfaceJson.PropertyJson[];
        methods: InterfaceJson.MethodJson[];
    }
    namespace InterfaceJson {
        interface PropertyJson extends ParserJson {
            parentId: number;
            comment: Misc.CommentJson;
            readonly: boolean;
            optional: boolean;
            type: TypeJson;
        }
        interface MethodJson extends ParserJson {
            parentId: number;
            signatures: Misc.SignatureJson[];
        }
    }
    interface NamespaceJson extends ParserJson {
        external: boolean;
        namespaceParentId: number | null;
        comment: Misc.CommentJson;
        classes: ClassJson[];
        enums: EnumJson[];
        functions: FunctionJson[];
        interfaces: InterfaceJson[];
        namespaces: NamespaceJson[];
        typeAliases: TypeAliasJson[];
        variables: VariableJson[];
    }
    interface TypeAliasJson extends ParserJson {
        external: boolean;
        namespaceParentId: number | null;
        comment: Misc.CommentJson;
        typeParameters: Misc.TypeParameterJson[];
        type: TypeJson;
    }
    interface VariableJson extends ParserJson {
        external: boolean;
        namespaceParentId: number | null;
        comment: Misc.CommentJson;
        type: TypeJson;
        value: string;
    }
}
//# sourceMappingURL=v10_1_0.d.ts.map