import { JSONOutput } from 'typedoc';
export interface ClassJson extends ParserJson {
    namespaceParentId: number | null;
    comment: Misc.CommentJson;
    external: boolean;
    abstract: boolean;
    extendsType: TypeJson | null;
    implementsType: TypeJson[];
    typeParameters: Misc.TypeParameterJson[];
    construct: ClassJson.ConstructorJson;
    properties: ClassJson.PropertyJson[];
    methods: ClassJson.MethodJson[];
}
export declare namespace ClassJson {
    enum Accessibility {
        Public = "public",
        Protected = "protected",
        Private = "private"
    }
    interface ConstructorJson extends ParserJson {
        comment: Misc.CommentJson;
        parentId: number;
        accessibility: Accessibility;
        parameters: Misc.ParameterJson[];
    }
    interface PropertyJson extends ParserJson {
        comment: Misc.CommentJson;
        parentId: number;
        accessibility: Accessibility;
        abstract: boolean;
        static: boolean;
        readonly: boolean;
        optional: boolean;
        type: TypeJson;
    }
    interface MethodJson extends ParserJson {
        parentId: number;
        accessibility: Accessibility;
        abstract: boolean;
        static: boolean;
        signatures: Misc.SignatureJson[];
    }
}
export interface EnumJson extends ParserJson {
    namespaceParentId: number | null;
    comment: Misc.CommentJson;
    external: boolean;
    members: EnumJson.MemberJson[];
}
export declare namespace EnumJson {
    interface MemberJson extends ParserJson {
        comment: Misc.CommentJson;
        parentId: number;
        value: string;
    }
}
export interface InterfaceJson extends ParserJson {
    namespaceParentId: number | null;
    comment: Misc.CommentJson;
    external: boolean;
    typeParameters: Misc.TypeParameterJson[];
    properties: InterfaceJson.PropertyJson[];
    methods: InterfaceJson.MethodJson[];
}
export declare namespace InterfaceJson {
    interface PropertyJson extends ParserJson {
        comment: Misc.CommentJson;
        parentId: number;
        readonly: boolean;
        type: TypeJson | null;
    }
    interface MethodJson extends ParserJson {
        parentId: number;
        signatures: Misc.SignatureJson[];
    }
}
export declare namespace Misc {
    interface CommentJson {
        description: string | null;
        blockTags: CommentJson.BlockTagJson[];
        modifierTags: string[];
    }
    namespace CommentJson {
        interface BlockTagJson {
            name: string;
            text: string;
        }
    }
    interface ParameterJson {
        id: number;
        name: string;
        comment: CommentJson;
        optional: boolean;
        rest: boolean;
        type: TypeJson;
    }
    interface SignatureJson {
        id: number;
        name: string;
        comment: CommentJson;
        typeParameters: TypeParameterJson[];
        parameters: ParameterJson[];
        returnType: TypeJson;
    }
    interface SourceJson {
        line: number;
        file: string;
        path: string;
        url: string | null;
    }
    interface TypeParameterJson {
        id: number;
        name: string;
        constraint: TypeJson | null;
        default: TypeJson | null;
    }
}
export interface TypeJson {
    kind: TypeJson.Kind;
}
export declare namespace TypeJson {
    interface ArrayJson extends TypeJson {
        kind: Kind.Array;
        type: TypeJson;
    }
    interface ConditionalJson extends TypeJson {
        kind: Kind.Conditional;
        checkType: TypeJson;
        extendsType: TypeJson;
        trueType: TypeJson;
        falseType: TypeJson;
    }
    interface IndexedAccessJson extends TypeJson {
        kind: Kind.IndexedAccess;
        objectType: TypeJson;
        indexType: TypeJson;
    }
    interface InferredJson extends TypeJson {
        kind: Kind.Inferred;
        type: string;
    }
    interface IntersectionJson extends TypeJson {
        kind: Kind.Intersection;
        types: TypeJson[];
    }
    interface IntrinsicJson extends TypeJson {
        kind: Kind.Intrinsic;
        type: string;
    }
    interface LiteralJson extends TypeJson {
        kind: Kind.Literal;
        value: string;
    }
    interface MappedJson extends TypeJson {
        kind: Kind.Mapped;
        parameter: string;
        parameterType: TypeJson;
        nameType: TypeJson | null;
        templateType: TypeJson;
        readonly: MappedJson.Modifier;
        optional: MappedJson.Modifier;
    }
    namespace MappedJson {
        enum Modifier {
            Add = "+",
            Remove = "-"
        }
    }
    interface NamedTupleMemberJson extends TypeJson {
        kind: Kind.NamedTupleMember;
        name: string;
        type: TypeJson;
        optional: boolean;
    }
    interface OptionalJson extends TypeJson {
        kind: Kind.Optional;
        type: TypeJson;
    }
    interface PredicateJson extends TypeJson {
        kind: Kind.Predicate;
        asserts: boolean;
        name: string;
        type: TypeJson | null;
    }
    interface QueryJson extends TypeJson {
        kind: Kind.Query;
        queryType: ReferenceJson;
    }
    interface ReferenceJson extends TypeJson {
        kind: Kind.Reference;
        id: number | null;
        name: string;
        packageName: string | null;
        typeArguments: TypeJson[];
    }
    interface ReflectionJson extends TypeJson {
        kind: Kind.Reflection;
        reflection: JSONOutput.DeclarationReflection | null;
    }
    interface RestJson extends TypeJson {
        kind: Kind.Rest;
        type: TypeJson;
    }
    interface TemplateLiteralJson extends TypeJson {
        kind: Kind.TemplateLiteral;
        head: string;
        tail: TemplateLiteralJson.TailJson[];
    }
    namespace TemplateLiteralJson {
        interface TailJson {
            type: TypeJson;
            text: string;
        }
    }
    interface TupleJson extends TypeJson {
        kind: Kind.Tuple;
        types: TypeJson[];
    }
    interface TypeOperatorJson extends TypeJson {
        kind: Kind.TypeOperator;
        operator: TypeOperatorJson.Operator;
        type: TypeJson;
    }
    namespace TypeOperatorJson {
        enum Operator {
            KeyOf = "keyof",
            Unique = "unique",
            Readonly = "readonly"
        }
    }
    interface UnionJson extends TypeJson {
        kind: Kind.Union;
        types: TypeJson[];
    }
    interface UnknownJson extends TypeJson {
        kind: Kind.Unknown;
        name: string;
    }
}
export declare namespace TypeJson {
    enum Kind {
        Array = "array",
        Conditional = "conditional",
        IndexedAccess = "indexedAccess",
        Inferred = "inferred",
        Intersection = "intersection",
        Intrinsic = "intrinsic",
        Literal = "literal",
        Mapped = "mapped",
        NamedTupleMember = "namedTupleMember",
        Optional = "optional",
        Predicate = "predicate",
        Query = "query",
        Reference = "reference",
        Reflection = "reflection",
        Rest = "rest",
        TemplateLiteral = "templateLiteral",
        Tuple = "tuple",
        TypeOperator = "typeOperator",
        Union = "union",
        Unknown = "unknown"
    }
}
export interface FunctionJson extends ParserJson {
    namespaceParentId: number | null;
    comment: Misc.CommentJson;
    external: boolean;
    signatures: Misc.SignatureJson[];
}
export interface NamespaceJson extends ParserJson {
    namespaceParentId: number | null;
    comment: Misc.CommentJson;
    external: boolean;
    classes: ClassJson[];
    variables: VariableJson[];
    enums: EnumJson[];
    functions: FunctionJson[];
    interfaces: InterfaceJson[];
    namespaces: NamespaceJson[];
    typeAliases: TypeAliasJson[];
}
export interface ParserJson {
    id: number;
    name: string;
    source: Misc.SourceJson | null;
}
export interface ProjectJson {
    typeDocJsonParserVersion: string;
    id: number;
    name: string;
    version: string | null;
    readme: string | null;
    changelog: string | null;
    classes: ClassJson[];
    variables: VariableJson[];
    enums: EnumJson[];
    functions: FunctionJson[];
    interfaces: InterfaceJson[];
    namespaces: NamespaceJson[];
    typeAliases: TypeAliasJson[];
}
export interface TypeAliasJson extends ParserJson {
    namespaceParentId: number | null;
    comment: Misc.CommentJson;
    external: boolean;
    typeParameters: Misc.TypeParameterJson[];
    type: TypeJson;
}
export interface VariableJson extends ParserJson {
    namespaceParentId: number | null;
    comment: Misc.CommentJson;
    external: boolean;
    type: TypeJson;
    value: string;
}
//# sourceMappingURL=Four.d.ts.map