import { SignatureParser } from '#lib/structures/misc';
import { JSONOutput } from 'typedoc';
export declare class MethodParser {
    /**
     * The identifier of this parser.
     * @since 8.1.0
     */
    readonly id: number;
    /**
     * The signature parsers of this method.
     * @since 8.1.0
     */
    readonly signatures: SignatureParser[];
    constructor(data: MethodParser.Data);
    /**
     * Converts this parser to a json compatible format.
     * @since 8.1.0
     * @returns The json compatible format of this parser.
     */
    toJSON(): MethodParser.Json;
    /**
     * Generates a new {@link MethodParser} instance from the given data.
     * @since 8.1.0
     * @param reflection The reflection to generate the parser from.
     * @returns The generated parser.
     */
    static generateFromTypeDoc(reflection: JSONOutput.DeclarationReflection): MethodParser;
    /**
     * Generates a new {@link MethodParser} instance from the given data.
     * @since 8.1.0
     * @param json The json to generate the parser from.
     * @returns The generated parser.
     */
    static generateFromJson(json: MethodParser.Json): MethodParser;
}
export declare namespace MethodParser {
    interface Data {
        /**
         * The identifier of this parser.
         * @since 8.1.0
         */
        id: number;
        /**
         * The signature parsers of this method.
         * @since 8.1.0
         */
        signatures: SignatureParser[];
    }
    interface Json {
        /**
         * The identifier of this parser in a json compatible format.
         * @since 8.1.0
         */
        id: number;
        /**
         * The signature parsers of this method in a json compatible format.
         * @since 8.1.0
         */
        signatures: SignatureParser.Json[];
    }
}
//# sourceMappingURL=MethodParser.d.ts.map