import { SignatureParser } from '#lib/structures/misc';
import { ReflectionKind } from '#lib/types';
import { JSONOutput } from 'typedoc';
export class MethodParser {
    /**
     * The identifier of this parser.
     * @since 8.1.0
     */
    id;
    /**
     * The signature parsers of this method.
     * @since 8.1.0
     */
    signatures;
    constructor(data) {
        const { id, signatures } = data;
        this.id = id;
        this.signatures = signatures;
    }
    /**
     * Converts this parser to a json compatible format.
     * @since 8.1.0
     * @returns The json compatible format of this parser.
     */
    toJSON() {
        return {
            id: this.id,
            signatures: this.signatures.map((signature) => signature.toJSON())
        };
    }
    /**
     * Generates a new {@link MethodParser} instance from the given data.
     * @since 8.1.0
     * @param reflection The reflection to generate the parser from.
     * @returns The generated parser.
     */
    static generateFromTypeDoc(reflection) {
        const { kind, id, signatures = [] } = reflection;
        if (kind !== ReflectionKind.Method) {
            throw new Error(`Expected Method (${ReflectionKind.Method}), but received ${kind} (${reflection.kind}). ID=${id}`);
        }
        return new MethodParser({
            id,
            signatures: signatures.map((signature) => SignatureParser.generateFromTypeDoc(signature))
        });
    }
    /**
     * Generates a new {@link MethodParser} instance from the given data.
     * @since 8.1.0
     * @param json The json to generate the parser from.
     * @returns The generated parser.
     */
    static generateFromJson(json) {
        const { id, signatures } = json;
        return new MethodParser({
            id,
            signatures: signatures.map((signature) => SignatureParser.generateFromJson(signature))
        });
    }
}
//# sourceMappingURL=MethodParser.js.map