import { CommentParser } from '#lib/structures/misc';
import { TypeParser } from '#lib/structures/type-parsers';
import type { JSONOutput } from 'typedoc';
/**
 * Parses data from a parameter reflection.
 * @since 1.0.0
 */
export declare class ParameterParser {
    /**
     * The identifier of this parser.
     * @since 1.0.0
     */
    readonly id: number;
    /**
     * The name of this parameter.
     * @since 1.0.0
     */
    readonly name: string;
    /**
     * The comment of this parameter.
     * @since 5.3.0
     */
    readonly comment: CommentParser;
    /**
     * Whether this is a rest parameter.
     * @since 7.2.0
     */
    readonly rest: boolean;
    /**
     * Whether this parameter is optional.
     * @since 7.1.0
     */
    readonly optional: boolean;
    /**
     * The type of this parameter.
     * @since 1.0.0
     */
    readonly type: TypeParser;
    constructor(data: ParameterParser.Data);
    /**
     * Converts this parser to a json compatible format.
     * @since 1.0.0
     * @returns The json compatible format of this parser.
     */
    toJSON(): ParameterParser.Json;
    /**
     * Generates a new {@link ParameterParser} instance from the given data.
     * @since 1.0.0
     * @param reflection The reflection to generate the parser from.
     * @returns The generated parser.
     */
    static generateFromTypeDoc(reflection: JSONOutput.ParameterReflection): ParameterParser;
    /**
     * Generates a new {@link ClassConstructorParser} instance from the given data.
     * @param json The json to generate the parser from.
     * @returns The generated parser.
     */
    static generateFromJson(json: ParameterParser.Json): ParameterParser;
}
export declare namespace ParameterParser {
    interface Data {
        /**
         * The identifier of this parser.
         * @since 1.0.0
         */
        id: number;
        /**
         * The name of this parameter.
         * @since 1.0.0
         */
        name: string;
        /**
         * The comment of this parameter.
         * @since 5.3.0
         */
        comment: CommentParser;
        /**
         * Whether this is a rest parameter.
         * @since 7.2.0
         */
        rest: boolean;
        /**
         * Whether this parameter is optional.
         * @since 7.1.0
         */
        optional: boolean;
        /**
         * The type of this parameter.
         * @since 1.0.0
         */
        type: TypeParser;
    }
    interface Json {
        /**
         * The identifier of this parser.
         * @since 1.0.0
         */
        id: number;
        /**
         * The name of this parameter.
         * @since 1.0.0
         */
        name: string;
        /**
         * The comment of this parameter.
         * @since 5.3.0
         */
        comment: CommentParser.Json;
        /**
         * Whether this is a rest parameter.
         * @since 7.2.0
         */
        rest: boolean;
        /**
         * Whether this parameter is optional.
         * @since 7.1.0
         */
        optional: boolean;
        /**
         * The type of this parameter in a json compatible format.
         * @since 1.0.0
         */
        type: TypeParser.Json;
    }
}
//# sourceMappingURL=ParameterParser.d.ts.map