import { CommentParser } from '#lib/structures/misc';
import { TypeParser } from '#lib/structures/type-parsers';
import { JSONOutput } from 'typedoc';
/**
 * Parses data from a property reflection.
 * @since 8.0.0
 */
export declare class PropertyParser {
    /**
     * The identifier of this parser.
     * @since 8.0.0
     */
    readonly id: number;
    /**
     * The name of this property.
     * @since 8.0.0
     */
    readonly name: string;
    /**
     * The comment of this property.
     * @since 8.0.0
     */
    readonly comment: CommentParser;
    /**
     * Whether this property is readonly.
     * @since 8.2.0
     */
    readonly readonly: boolean;
    /**
     * Whether this property is optional.
     * @since 8.2.0
     */
    readonly optional: boolean;
    /**
     * The type of this property.
     * @since 8.0.0
     */
    readonly type: TypeParser;
    constructor(data: PropertyParser.Data);
    /**
     * Converts this parser to a json compatible format.
     * @since 8.0.0
     * @returns The json compatible format of this parser.
     */
    toJSON(): PropertyParser.Json;
    /**
     * Generates a new {@link PropertyParser} instance from the given data.
     * @since 8.0.0
     * @param reflection The reflection to generate the parser from.
     * @returns The generated parser.
     */
    static generateFromTypeDoc(reflection: JSONOutput.DeclarationReflection): PropertyParser;
    /**
     * Generates a new {@link PropertyParser} instance from the given data.
     * @since 8.0.0
     * @param json The json to generate the parser from.
     * @returns The generated parser.
     */
    static generateFromJson(json: PropertyParser.Json): PropertyParser;
}
export declare namespace PropertyParser {
    interface Data {
        /**
         * The identifier of this parser.
         * @since 8.0.0
         */
        id: number;
        /**
         * The name of this property.
         * @since 8.0.0
         */
        name: string;
        /**
         * The comment of this property.
         * @since 8.0.0
         */
        comment: CommentParser;
        /**
         * Whether this property is readonly.
         * @since 8.2.0
         */
        readonly: boolean;
        /**
         * Whether this property is optional.
         * @since 8.2.0
         */
        optional: boolean;
        /**
         * The type of this property.
         * @since 8.0.0
         */
        type: TypeParser;
    }
    interface Json {
        /**
         * The identifier of this parser in a json compatible format.
         * @since 8.0.0
         */
        id: number;
        /**
         * The name of this property in a json compatible format.
         * @since 8.0.0
         */
        name: string;
        /**
         * The comment of this property in a json compatible format.
         * @since 8.0.0
         */
        comment: CommentParser.Json;
        /**
         * Whether this property is readonly in a json compatible format.
         * @since 8.2.0
         */
        readonly: boolean;
        /**
         * Whether this property is optional in a json compatible format.
         * @since 8.2.0
         */
        optional: boolean;
        /**
         * The type of this property in a json compatible format.
         * @since 8.0.0
         */
        type: TypeParser.Json;
    }
}
//# sourceMappingURL=PropertyParser.d.ts.map