import { TypeParser } from '#lib/structures/type-parsers';
/**
 * Parses data for an indexed access type.
 * @since 1.0.0
 */
export class IndexedAccessTypeParser {
    /**
     * The kind of type this parser is for.
     * @since 1.0.0
     */
    kind = TypeParser.Kind.IndexedAccess;
    /**
     * The object type of this indexed access type.
     * @since 1.0.0
     */
    objectType;
    /**
     * The index type of this indexed access type.
     * @since 1.0.0
     */
    indexType;
    constructor(data) {
        const { objectType, indexType } = data;
        this.objectType = objectType;
        this.indexType = indexType;
    }
    /**
     * Converts this parser to a json compatible format.
     * @since 1.0.0
     * @returns The json compatible format of this parser.
     */
    toJSON() {
        return {
            kind: this.kind,
            objectType: this.objectType.toJSON(),
            indexType: this.indexType.toJSON()
        };
    }
    /**
     * Converts this parser to a string.
     * @since 1.0.0
     * @returns The string representation of this parser.
     */
    toString(project) {
        return IndexedAccessTypeParser.formatToString({ parser: this, project });
    }
    /**
     * Formats this type parser to a string.
     * @since 4.0.0
     * @param options The options to format this type parser to a string.
     * @returns The string representation of this parser.
     */
    static formatToString(options) {
        const { parser, project } = options;
        return `${parser.objectType.toString(project)}[${parser.indexType.toString(project)}]`;
    }
}
//# sourceMappingURL=IndexedAccessTypeParser.js.map