import { TypeParser } from '#lib/structures/type-parsers';
/**
 * Parses data for an inferred type.
 * @since 1.0.0
 */
export class InferredTypeParser {
    /**
     * The kind of type this parser is for.
     * @since 1.0.0
     */
    kind = TypeParser.Kind.Inferred;
    /**
     * The type of this inferred type.
     * @since 1.0.0
     */
    type;
    constructor(data) {
        const { type } = data;
        this.type = type;
    }
    /**
     * Converts this parser to a json compatible format.
     * @since 1.0.0
     * @returns The json compatible format of this parser.
     */
    toJSON() {
        return {
            kind: this.kind,
            type: this.type
        };
    }
    /**
     * Converts this parser to a string.
     * @since 1.0.0
     * @returns The string representation of this parser.
     */
    toString(project) {
        return InferredTypeParser.formatToString({ parser: this, project });
    }
    /**
     * Formats this type parser to a string.
     * @since 4.0.0
     * @param options The options to format this type parser to a string.
     * @returns The string representation of this parser.
     */
    static formatToString(options) {
        const { parser } = options;
        return `infer ${parser.type}`;
    }
}
//# sourceMappingURL=InferredTypeParser.js.map