import { TypeParser } from '#lib/structures/type-parsers';
/**
 * Parses data for a literal type.
 * @since 1.0.0
 */
export class LiteralTypeParser {
    /**
     * The kind of type this parser is for.
     * @since 1.0.0
     */
    kind = TypeParser.Kind.Literal;
    /**
     * The value of this literal type.
     * @since 1.0.0
     */
    value;
    constructor(data) {
        const { value } = data;
        this.value = value;
    }
    /**
     * Converts this parser to a json compatible format.
     * @since 1.0.0
     * @returns The json compatible format of this parser.
     */
    toJSON() {
        return {
            kind: this.kind,
            value: this.value
        };
    }
    /**
     * Converts this parser to a string.
     * @since 1.0.0
     * @returns The string representation of this parser.
     */
    toString(project) {
        return LiteralTypeParser.formatToString({ parser: this, project });
    }
    /**
     * Formats this type parser to a string.
     * @since 4.0.0
     * @param options The options to format this type parser to a string.
     * @returns The string representation of this parser.
     */
    static formatToString(options) {
        const { parser } = options;
        return parser.value;
    }
}
//# sourceMappingURL=LiteralTypeParser.js.map