import { TypeParser } from '#lib/structures/type-parsers';
/**
 * Parses data for a named tuple member.
 * @since 1.0.0
 */
export class NamedTupleMemberTypeParser {
    /**
     * The name of this named tuple member.
     * @since 1.0.0
     */
    kind = TypeParser.Kind.NamedTupleMember;
    /**
     * The name of this named tuple member.
     * @since 1.0.0
     */
    name;
    /**
     * The type of this named tuple member.
     * @since 1.0.0
     */
    type;
    /**
     * Whether this named tuple member is optional.
     * @since 1.0.0
     */
    optional;
    constructor(data) {
        const { name, type, optional } = data;
        this.name = name;
        this.type = type;
        this.optional = optional;
    }
    /**
     * Converts this parser to a json compatible format.
     * @since 1.0.0
     * @returns The json compatible format of this parser.
     */
    toJSON() {
        return {
            kind: this.kind,
            name: this.name,
            type: this.type.toJSON(),
            optional: this.optional
        };
    }
    /**
     * Converts this parser to a string.
     * @since 1.0.0
     * @returns The string representation of this parser.
     */
    toString(project) {
        return NamedTupleMemberTypeParser.formatToString({ parser: this, project });
    }
    /**
     * Formats this type parser to a string.
     * @since 4.0.0
     * @param options The options to format this type parser to a string.
     * @returns The string representation of this parser.
     */
    static formatToString(options) {
        const { parser, project } = options;
        return `${parser.name}${parser.optional ? '?' : ''}: ${parser.type.toString(project)}`;
    }
}
//# sourceMappingURL=NamedTupleMemberTypeParser.js.map