import { TypeParser } from '#lib/structures/type-parsers';
/**
 * Parses data for an optional type.
 * @since 1.0.0
 */
export class OptionalTypeParser {
    /**
     * The kind of type this parser is for.
     * @since 1.0.0
     */
    kind = TypeParser.Kind.Optional;
    /**
     * The type of this optional type.
     * @since 1.0.0
     */
    type;
    constructor(data) {
        const { type } = data;
        this.type = type;
    }
    /**
     * Converts this parser to a json compatible format.
     * @since 1.0.0
     * @returns The json compatible format of this parser.
     */
    toJSON() {
        return {
            kind: this.kind,
            type: this.type.toJSON()
        };
    }
    /**
     * Converts this parser to a string.
     * @since 1.0.0
     * @returns The string representation of this parser.
     */
    toString(project) {
        return OptionalTypeParser.formatToString({ parser: this, project });
    }
    /**
     * Formats this type parser to a string.
     * @since 4.0.0
     * @param options The options to format this type parser to a string.
     * @returns The string representation of this parser.
     */
    static formatToString(options) {
        const { parser, project } = options;
        return `${TypeParser.wrap(parser.type, TypeParser.BindingPowers[TypeParser.Kind.Optional], project)}?`;
    }
}
//# sourceMappingURL=OptionalTypeParser.js.map