import { TypeParser } from '#lib/structures/type-parsers';
/**
 * Parses data for a query type.
 * @since 1.0.0
 */
export class QueryTypeParser {
    /**
     * The kind of type this parser is for.
     * @since 1.0.0
     */
    kind = TypeParser.Kind.Query;
    /**
     * The query of this query type.
     * @since 1.0.0
     */
    query;
    constructor(data) {
        const { query } = data;
        this.query = query;
    }
    /**
     * Converts this parser to a json compatible format.
     * @since 1.0.0
     * @returns The json compatible format of this parser.
     */
    toJSON() {
        return {
            kind: this.kind,
            query: this.query.toJSON()
        };
    }
    /**
     * Converts this parser to a string.
     * @since 1.0.0
     * @returns The string representation of this parser.
     */
    toString(project) {
        return QueryTypeParser.formatToString({ parser: this, project });
    }
    /**
     * Formats this type parser to a string.
     * @since 4.0.0
     * @param options The options to format this type parser to a string.
     * @returns The string representation of this parser.
     */
    static formatToString(options) {
        const { parser, project } = options;
        return `typeof ${parser.query.toString(project)}`;
    }
}
//# sourceMappingURL=QueryTypeParser.js.map