import type { ProjectParser } from '#lib/structures/ProjectParser';
import { MethodParser, PropertyParser, SignatureParser } from '#lib/structures/misc';
import { TypeParser } from '#lib/structures/type-parsers';
/**
 * Parses data for a reflection type.
 * @since 1.0.0
 */
export declare class ReflectionTypeParser implements TypeParser {
    /**
     * The kind of type this parser is for.
     * @since 1.0.0
     */
    readonly kind = TypeParser.Kind.Reflection;
    /**
     * The properties of this reflection type.
     * @since 8.0.0
     */
    properties: PropertyParser[] | null;
    /**
     * The signatures of this reflection type.
     * @since 8.0.0
     */
    signatures: SignatureParser[] | null;
    /**
     * The methods of this reflection type.
     * @since 8.1.0
     */
    methods: MethodParser[] | null;
    constructor(data: ReflectionTypeParser.Data);
    /**
     * Converts this parser to a json compatible format.
     * @since 1.0.0
     * @returns The json compatible format of this parser.
     */
    toJSON(): ReflectionTypeParser.Json;
    /**
     * Converts this parser to a string.
     * @since 1.0.0
     * @returns The string representation of this parser.
     */
    toString(project?: ProjectParser): string;
    /**
     * Formats this type parser to a string.
     * @since 4.0.0
     * @param options The options to format this type parser to a string.
     * @returns The string representation of this parser.
     */
    static formatToString(options: TypeParser.FormatToStringOptions<ReflectionTypeParser>): string;
}
export declare namespace ReflectionTypeParser {
    interface Data {
        /**
         * The properties of this reflection type.
         * @since 8.0.0
         */
        properties: PropertyParser[] | null;
        /**
         * The signatures of this reflection type.
         * @since 8.0.0
         */
        signatures: SignatureParser[] | null;
        /**
         * The methods of this reflection type.
         * @since 8.1.0
         */
        methods: MethodParser[] | null;
    }
    interface Json extends TypeParser.Json {
        kind: TypeParser.Kind.Reflection;
        /**
         * The properties of this reflection type in a json compatible format.
         * @since 8.0.0
         */
        properties: PropertyParser.Json[] | null;
        /**
         * The signatures of this reflection type in a json compatible format.
         * @since 8.0.0
         */
        signatures: SignatureParser.Json[] | null;
        /**
         * The methods of this reflection type in a json compatible format.
         * @since 8.1.0
         */
        methods: MethodParser.Json[] | null;
    }
}
//# sourceMappingURL=ReflectionTypeParser.d.ts.map