import { TypeParser } from '#lib/structures/type-parsers';
/**
 * Parses data for a template literal type.
 * @since 1.0.0
 */
export class TemplateLiteralTypeParser {
    /**
     * The kind of type this parser is for.
     * @since 1.0.0
     */
    kind = TypeParser.Kind.TemplateLiteral;
    /**
     * The head of this template literal type.
     * @since 1.0.0
     */
    head;
    /**
     * The tail of this template literal type.
     * @since 1.0.0
     */
    tail;
    constructor(data) {
        const { head, tail } = data;
        this.head = head;
        this.tail = tail;
    }
    /**
     * Converts this parser to a json compatible format.
     * @since 1.0.0
     * @returns The json compatible format of this parser.
     */
    toJSON() {
        return {
            kind: this.kind,
            head: this.head,
            tail: this.tail.map((tail) => ({ type: tail.type.toJSON(), text: tail.text }))
        };
    }
    /**
     * Converts this parser to a string.
     * @since 1.0.0
     * @returns The string representation of this parser.
     */
    toString(project) {
        return TemplateLiteralTypeParser.formatToString({ parser: this, project });
    }
    /**
     * Formats this type parser to a string.
     * @since 4.0.0
     * @param options The options to format this type parser to a string.
     * @returns The string representation of this parser.
     */
    static formatToString(options) {
        const { parser, project } = options;
        return `\`${parser.head}${parser.tail.map((tail) => `\${${tail.type.toString(project)}}${tail.text}`).join('')}\``;
    }
}
//# sourceMappingURL=TemplateLiteralTypeParser.js.map