import { TypeParser } from '#lib/structures/type-parsers';
/**
 * Parses data for a tuple type.
 * @since 1.0.0
 */
export class TupleTypeParser {
    /**
     * The kind of type this parser is for.
     * @since 1.0.0
     */
    kind = TypeParser.Kind.Tuple;
    /**
     * The types of this tuple type.
     * @since 1.0.0
     */
    types;
    constructor(data) {
        const { types } = data;
        this.types = types;
    }
    /**
     * Converts this parser to a json compatible format.
     * @since 1.0.0
     * @returns The json compatible format of this parser.
     */
    toJSON() {
        return {
            kind: this.kind,
            types: this.types.map((type) => type.toJSON())
        };
    }
    /**
     * Converts this parser to a string.
     * @since 1.0.0
     * @returns The string representation of this parser.
     */
    toString(project) {
        return TupleTypeParser.formatToString({ parser: this, project });
    }
    /**
     * Formats this type parser to a string.
     * @since 4.0.0
     * @param options The options to format this type parser to a string.
     * @returns The string representation of this parser.
     */
    static formatToString(options) {
        const { parser, project } = options;
        return `[${parser.types.map((type) => type.toString(project)).join(', ')}]`;
    }
}
//# sourceMappingURL=TupleTypeParser.js.map