import { TypeParser } from '#lib/structures/type-parsers';
/**
 * Parses data for a type operator type.
 * @since 1.0.0
 */
export class TypeOperatorTypeParser {
    /**
     * The kind of type this parser is for.
     * @since 1.0.0
     */
    kind = TypeParser.Kind.TypeOperator;
    /**
     * The operator of this type operator type.
     * @since 1.0.0
     */
    operator;
    /**
     * The type of this type operator type.
     * @since 1.0.0
     */
    type;
    constructor(data) {
        const { operator, type } = data;
        this.operator = operator;
        this.type = type;
    }
    /**
     * Converts this parser to a json compatible format.
     * @since 1.0.0
     * @returns The json compatible format of this parser.
     */
    toJSON() {
        return {
            kind: this.kind,
            operator: this.operator,
            type: this.type.toJSON()
        };
    }
    /**
     * Converts this parser to a string.
     * @since 1.0.0
     * @returns The string representation of this parser.
     */
    toString(project) {
        return TypeOperatorTypeParser.formatToString({ parser: this, project });
    }
    /**
     * Formats this type parser to a string.
     * @since 4.0.0
     * @param options The options to format this type parser to a string.
     * @returns The string representation of this parser.
     */
    static formatToString(options) {
        const { parser, project } = options;
        return `${parser.operator} ${parser.type.toString(project)}`;
    }
}
(function (TypeOperatorTypeParser) {
    /**
     * The operators of a type operator type.
     */
    let Operator;
    (function (Operator) {
        Operator["KeyOf"] = "keyof";
        Operator["Unique"] = "unique";
        Operator["Readonly"] = "readonly";
    })(Operator = TypeOperatorTypeParser.Operator || (TypeOperatorTypeParser.Operator = {}));
})(TypeOperatorTypeParser || (TypeOperatorTypeParser = {}));
//# sourceMappingURL=TypeOperatorTypeParser.js.map