import { TypeParser } from '#lib/structures/type-parsers';
/**
 * Parses data for an unknown type.
 * @since 1.0.0
 */
export class UnknownTypeParser {
    /**
     * The kind of type this parser is for.
     * @since 1.0.0
     */
    kind = TypeParser.Kind.Unknown;
    /**
     * The name of this unknown type.
     * @since 1.0.0
     */
    name;
    constructor(data) {
        const { name } = data;
        this.name = name;
    }
    /**
     * Converts this parser to a json compatible format.
     * @since 1.0.0
     * @returns The json compatible format of this parser.
     */
    toJSON() {
        return {
            kind: this.kind,
            name: this.name
        };
    }
    /**
     * Converts this parser to a string.
     * @since 1.0.0
     * @returns The string representation of this parser.
     */
    toString(project) {
        return UnknownTypeParser.formatToString({ parser: this, project });
    }
    /**
     * Formats this type parser to a string.
     * @since 4.0.0
     * @param options The options to format this type parser to a string.
     * @returns The string representation of this parser.
     */
    static formatToString(options) {
        const { parser } = options;
        return parser.name;
    }
}
//# sourceMappingURL=UnknownTypeParser.js.map